﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace CustomLegendLabel
{
    public class CustomLegend : ContentPage
    {
        ObservableCollection<ChartDataPoint> datas;

        SfChart chart;

        StackLayout rootLayout;

        List<Color> customColors;

        StackLayout legendLayout;

        BoxView boxView;

        Label label;

        ScrollView scrollView;

        public CustomLegend()
        {
            customColors = new List<Color>();

            datas = new ObservableCollection<ChartDataPoint>();

            rootLayout = new StackLayout();
            rootLayout.BackgroundColor = Color.White;

            scrollView = new ScrollView();              
            scrollView.Orientation = ScrollOrientation.Horizontal;

            chart = new SfChart();
            chart.VerticalOptions = LayoutOptions.FillAndExpand;
            chart.HorizontalOptions = LayoutOptions.FillAndExpand;

            chart.PrimaryAxis = new CategoryAxis()
            {
                ZoomFactor = 0.5,
                ZoomPosition = 0           
            };
            chart.SecondaryAxis = new NumericalAxis();

            datas.Add(new ChartDataPoint("Hubert\nBlaine", 80));
            datas.Add(new ChartDataPoint("Steve\nSmith", 130));
            datas.Add(new ChartDataPoint("Dawn\nMcManus", 100));
            datas.Add(new ChartDataPoint("David\nJohn", 150));
            datas.Add(new ChartDataPoint("Deepak\nRaj", 140));
            datas.Add(new ChartDataPoint("Dawn\nMcManus", 100));
            datas.Add(new ChartDataPoint("David\nJohn", 150));
            datas.Add(new ChartDataPoint("Deepak\nRaj", 140));

            for (int i = 0; i < datas.Count; i++)
            {
                var colors = GetValues(datas[i].YValue);
                customColors.Add(colors.Item1);
            }

            DataTemplate template = new DataTemplate(() => {
                StackLayout stack = new StackLayout() { Orientation = StackOrientation.Horizontal };
                Label ylabel = new Label() { Text = "YValue is:" };
                Label yValue = new Label();
                yValue.SetBinding(Label.TextProperty, "YValue");
                stack.Children.Add(ylabel);
                stack.Children.Add(yValue);
                return stack;
            });

            ColumnSeries columnSeries = new ColumnSeries();
            columnSeries.ColorModel.Palette = ChartColorPalette.Custom;
            columnSeries.ColorModel.CustomBrushes = customColors;
            columnSeries.EnableTooltip = true;
            columnSeries.TooltipTemplate = template;
            columnSeries.DataMarker = new ChartDataMarker();
            columnSeries.ItemsSource = datas;

            chart.Series.Add(columnSeries);
            chart.ChartBehaviors.Add(new ChartZoomPanBehavior()
            {
                EnableDoubleTap = false,
                EnableZooming = false
            });

            legendLayout = new StackLayout();
            legendLayout.Orientation = StackOrientation.Horizontal;
            legendLayout.BackgroundColor = Color.White;
            legendLayout.Padding = new Thickness(10, 10, 0, 15);

            label = new Label();

            for (int i = 0; i < datas.Count; i++)
            {
                var legendItemContainer = new StackLayout();
                legendItemContainer.Orientation = StackOrientation.Horizontal;

                boxView = new BoxView();
                boxView.WidthRequest = 20;
                boxView.HeightRequest = 5;
                var item = GetValues(datas[i].YValue);
                boxView.Color = item.Item1;
                legendLayout.Children.Add(boxView);

                label = new Label();
                label.TextColor = Color.Black;
                label.FontSize = 15;
                label.Text = item.Item2;
                legendLayout.Children.Add(label);
            }

            scrollView.Content = legendLayout;
            rootLayout.Children.Add(scrollView);
            rootLayout.Orientation = StackOrientation.Vertical;
            rootLayout.Children.Add(chart);

            Content = rootLayout;
        }
        public Tuple<Color, string> GetValues(double yValue)
        {
            if (yValue >= 0 && yValue < 75)
            {
                return Tuple.Create(Color.Red, "Below threshold");
            }
            else if (yValue >= 75 && yValue < 100)
            {
                return Tuple.Create(Color.FromHex("FFFEBE17"), "between threshold and target");
            }
            else if (yValue >= 100 && yValue < 150)
            {
                return Tuple.Create(Color.Green, "Above target and below excellence");
            }
            else
            {
                return Tuple.Create(Color.Blue, "Above excellence");
            }
        }
    }
}
